"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var config_system_1 = require("./config-system");
var fs = require("fs");
var jwtDecode = require("jwt-decode");
var config_1 = require("./config");
var JWTPrefix = "eyJhbGciOiJSUzUxMiIsInR5cCI6IkpXVCJ9.";
var ConfigLoader = /** @class */ (function () {
    function ConfigLoader(logger) {
        this.logger = logger;
    }
    ConfigLoader.prototype.loadAgentConfiguration = function (initialJsonConfig) {
        //1. Defaults
        var agentCfg = new config_1.AgentConfig();
        /**
         * 2. This is how the cli program, executed on the parent process, communicates with this process.
         * This configuration takes precedence over other environment variables
         */
        if (process.env.SL_CONFIGURATION) {
            try {
                var jsonCfg = JSON.parse(process.env.SL_CONFIGURATION);
                agentCfg.loadConfiguration(new config_system_1.JsonObjectConfigurationProvider(jsonCfg));
            }
            catch (e) {
                console.error("Error parsing agent configuration", e);
                //TODO: Log
            }
        }
        //3. Env variables
        agentCfg.loadConfiguration(new config_system_1.EnvVariableConfigurationProvider("SL_"));
        //4. Overwrite file config with runtimeCfg provided by the user
        if (initialJsonConfig) {
            agentCfg.loadConfiguration(new config_system_1.JsonObjectConfigurationProvider(initialJsonConfig));
        }
        if (!agentCfg.token.hasValue && agentCfg.tokenFile.hasValue) {
            try {
                agentCfg.token.value = fs.readFileSync(agentCfg.tokenFile.value).toString();
            }
            catch (err) {
                //TODO: LOG
            }
        }
        //6. Load from token
        if (agentCfg.token.hasValue) {
            this.loadConfigFromToken(agentCfg, agentCfg.token.value);
        }
        this.printConfiguration(agentCfg);
        //Rest of configuration will be overridden by server cfg (after agent is loaded)
        return agentCfg;
    };
    ConfigLoader.prototype.printConfiguration = function (agentCfg) {
        if (!this.logger)
            return;
        this.logger.info("****************************************************");
        this.logger.info("Current config");
        this.logger.info("****************************************************");
        this.logger.info(agentCfg.toJsonObject());
    };
    ConfigLoader.prototype.loadConfigFromToken = function (agentCfg, token) {
        if (!token)
            return null;
        try {
            var tokenData = jwtDecode(token);
            if (!tokenData["x-sl-server"]) {
                throw new Error("Token Is Invalid. Doesn't Contain Server");
            }
            if (!tokenData["subject"]) {
                throw new Error("Token Is Invalid. Doesn't Contain Subject");
            }
            var customerId = tokenData["subject"];
            var subjectParts = tokenData["subject"].split("@");
            if (subjectParts.length >= 1) {
                customerId = subjectParts[0];
            }
            if (!agentCfg.server.hasValue) {
                agentCfg.server.value = tokenData["x-sl-server"];
            }
            agentCfg.customerId.value = customerId;
        }
        catch (err) {
            //TODO: LOG
        }
    };
    return ConfigLoader;
}());
exports.ConfigLoader = ConfigLoader;
//# sourceMappingURL=config-loader.js.map