"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var contracts_1 = require("./contracts");
var unique_id_converter_1 = require("./unique-id-converter");
/*
    this class create uniqueId's in new format but the input is from istanbul.
 */
var IstanbulUniqueIdConverter = /** @class */ (function (_super) {
    __extends(IstanbulUniqueIdConverter, _super);
    function IstanbulUniqueIdConverter(filename, logger) {
        return _super.call(this, filename, logger) || this;
    }
    IstanbulUniqueIdConverter.prototype.createElementsArray = function (file) {
        var _this = this;
        file.fnMap = file.fnMap || {};
        file.branchMap = file.branchMap || {};
        var methodsArr = Object.keys(file.fnMap).map(function (key) { return _this.formatMethod(file.fnMap[key]); });
        var branchesArr = this.createBranchElements(file.branchMap);
        this.fillFileElementsArray(methodsArr, this.methodsArray, contracts_1.ElementType.METHOD);
        this.fillFileElementsArray(branchesArr, this.branchesArray, contracts_1.ElementType.BRANCH);
    };
    IstanbulUniqueIdConverter.prototype.createElementPosition = function (position) {
        return position;
    };
    IstanbulUniqueIdConverter.prototype.createBranchElements = function (branchesMap) {
        var branchesMapArr = Object.keys(branchesMap).map(function (key) { return branchesMap[key]; });
        var branchesArr = [];
        for (var _i = 0, branchesMapArr_1 = branchesMapArr; _i < branchesMapArr_1.length; _i++) {
            var branch = branchesMapArr_1[_i];
            branchesArr = branchesArr.concat(this.extractBranchParts(branch));
        }
        return branchesArr;
    };
    /*
        in istanbul data branches has 'locations' array which described all parts of current condition,
        for example: if/else statement will take 2 locations one for the 'if' and one for the 'else'
     */
    IstanbulUniqueIdConverter.prototype.extractBranchParts = function (branch) {
        var formattedBranches = [];
        var locations = branch.locations;
        for (var i = 0; i < locations.length; i++) {
            var element = {};
            element.position = locations[i].start;
            element.endPosition = locations[i].end;
            element.uniqueId = this.filename + "|" + this.formatLoc(element.position) + "|" + i;
            formattedBranches.push(element);
        }
        return formattedBranches;
    };
    IstanbulUniqueIdConverter.prototype.formatMethod = function (method) {
        var element = {};
        element.position = method.loc.start;
        element.endPosition = method.loc.end;
        element.uniqueId = this.filename + "@" + this.formatLoc(method.loc.start);
        if (method.decl && method.decl.start) {
            element.uniqueId_decl = this.filename + "@" + this.formatLoc(method.decl.start);
            /*
                if method body located in different row from declaration we want to align with build scanner so we take
                the declaration as position.
                i.e: function a()
                {
                    do something...
                }
                in that case the 'decl' object will point one line before 'loc' object.
                but in the following example 'decl' and 'loc' points the same line:
                function a(){
                    do something...
                }
             */
            if (method.decl.start.line < method.loc.start.line) {
                element.position = method.decl.start;
            }
        }
        return element;
    };
    IstanbulUniqueIdConverter.prototype.formatLoc = function (loc) {
        return loc.line + "," + loc.column;
    };
    return IstanbulUniqueIdConverter;
}(unique_id_converter_1.UniqueIdConverter));
exports.IstanbulUniqueIdConverter = IstanbulUniqueIdConverter;
//# sourceMappingURL=istanbul-unique-id-converter.js.map