"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var os = require("os");
var version = require("../../package.json").version;
function clone(o) {
    //if (!o) return o; //Unreachable
    return JSON.parse(JSON.stringify(o));
}
/**
 * The service is used to get environmental data for submission (process id, machine data, etc.)
 */
var EnvironmentDataService = /** @class */ (function () {
    function EnvironmentDataService(cfg) {
        this.cfg = cfg;
        this.envData = null;
        if (!cfg)
            throw new Error("cfg is required");
        this.envData = {
            machineName: os.hostname(),
            platform: os.platform(),
            processArgv: process.argv,
            os: os.type(),
            osVersion: os.release(),
            arch: os.arch(),
            processId: process.pid,
            ipAddress: clone(os.networkInterfaces()),
            dependencies: clone(process.versions),
            runtime: process.version,
            agentType: "nodejs",
            agentVersion: version,
        };
        if (cfg && cfg.environmentName.hasValue) {
            this.envData.environmentName = cfg.environmentName.value;
        }
        if (cfg && cfg.labId.hasValue) {
            this.envData.labId = cfg.labId.value;
        }
        if (cfg && cfg.testStage.hasValue) {
            this.envData.testStage = cfg.testStage.value;
        }
    }
    EnvironmentDataService.prototype.getEnvDataForSubmission = function () {
        var returnedEnvData = clone(this.envData);
        returnedEnvData.memory = {
            process: process.memoryUsage(),
            machine: {
                freemem: os.freemem(),
                totalmem: os.totalmem(),
            },
        };
        this.setLastError(null);
        return returnedEnvData;
    };
    EnvironmentDataService.prototype.setLastError = function (message) {
        this.envData.lastError = message;
    };
    return EnvironmentDataService;
}());
exports.EnvironmentDataService = EnvironmentDataService;
//# sourceMappingURL=environment-data-service.js.map