"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var os = require("os");
var sl_env_vars_1 = require("../constants/sl-env-vars");
var path = require("path");
var http_client_1 = require("../http/http-client");
var messages_formatter_1 = require("../messages-formatter");
var sl_routes_1 = require("../http/sl-routes");
var validation_utils_1 = require("../utils/validation-utils");
var FILE_NOT_FOUND_CODE = 'ENOENT';
var ProductionFootprintsHandler = /** @class */ (function () {
    function ProductionFootprintsHandler(cfg, logger) {
        this.validateConfig(cfg);
        this.agentConfig = cfg;
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(logger, "logger");
        this.logger = logger;
        this.metaData = new MetaData(cfg.buildSessionId.value, cfg.labId.value);
        this.filename = this.createFilePath(cfg); //Todo: remove or make saving to file configurable
        this.collectionStartDate = new Date().valueOf();
        this.methodIdToHits = {};
        this.initHttpConfig(cfg);
        this.httpClient = new http_client_1.HttpClient(this.httpConfig, logger);
        this.setupProdListenerModes();
    }
    ProductionFootprintsHandler.prototype.setupProdListenerModes = function () {
        var prodListenerModes = sl_env_vars_1.SlEnvVars.getProductionListenerModes();
        if (prodListenerModes.length == 0 || (prodListenerModes.length == 1 && prodListenerModes[0] == 'true')) {
            //Defaults in case the production listener env var is not present or is set to 'true'
            this.sendToServer = true;
            this.saveToFile = false;
        }
        else {
            this.sendToServer = prodListenerModes.indexOf('server') > -1;
            this.saveToFile = prodListenerModes.indexOf('file') > -1;
        }
        this.logger.info("Production listener send to server: " + this.sendToServer + ", save to file: " + this.saveToFile);
    };
    ProductionFootprintsHandler.prototype.initHttpConfig = function (cfg) {
        var config = {
            token: cfg.token.value,
            server: cfg.server.value,
            proxy: cfg.proxy.value,
            compressRequests: cfg.gzip.hasValue ? cfg.gzip.value : true
        };
        this.httpConfig = config;
    };
    ProductionFootprintsHandler.prototype.handleFootprints = function (footprintsPacket, callback) {
        if (!footprintsPacket) {
            this.logger.info("Handle footprints - got null or empty packet. Skip saving.");
            callback(null);
            return;
        }
        if (!footprintsPacket || !footprintsPacket.apps || !footprintsPacket.apps[0] || !footprintsPacket.apps[0].files) {
            this.logger.info("Handle footprints - no footprints data. Skip saving.");
            callback(null);
            return;
        }
        this.saveAndSendMethodsHits(footprintsPacket)
            .then(function () { return callback(null); })
            .catch(function (err) { return callback(err); });
    };
    ProductionFootprintsHandler.prototype.saveAndSendMethodsHits = function (packetToSend) {
        return __awaiter(this, void 0, void 0, function () {
            var hitFiles;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        hitFiles = this.getHitFiles(packetToSend);
                        this.logger.debug("Submitting production data, files: %s, toServer: %s, toFile: %s (%s)", hitFiles, this.sendToServer, this.saveToFile, this.filename);
                        if (!this.sendToServer) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.convertAndSubmitToServer(packetToSend)];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        if (!this.saveToFile) return [3 /*break*/, 5];
                        this.methodIdToHits = {};
                        this.addHitsFromFootprints(packetToSend.apps[0].files);
                        return [4 /*yield*/, this.addHitsFromFile()];
                    case 3:
                        _a.sent();
                        return [4 /*yield*/, this.writeDataToFile()];
                    case 4:
                        _a.sent();
                        _a.label = 5;
                    case 5: return [2 /*return*/];
                }
            });
        });
    };
    ProductionFootprintsHandler.prototype.getHitFiles = function (packetToSend) {
        if (!this.logger.debug()) {
            return;
        }
        var formatter = new messages_formatter_1.MessagesFormatter();
        if (packetToSend && packetToSend.apps && packetToSend.apps[0] && packetToSend.apps[0].files) {
            packetToSend.apps[0].files.forEach(function (file) {
                formatter.addContent(file.path);
            });
        }
        return formatter.content;
    };
    ProductionFootprintsHandler.prototype.convertFootprintsToProductionData = function (footprintsPacket) {
        var now = new Date().valueOf();
        var productionDataPacket = {
            meta: {
                appName: this.agentConfig.appName.value,
                branchName: this.agentConfig.branch.value,
                buildName: this.agentConfig.build.value,
                bsid: this.agentConfig.buildSessionId.value,
                createdAt: this.collectionStartDate,
                lastModified: now,
                customerId: this.agentConfig.customerId.value,
                hostName: os.hostname(),
                pid: process.pid,
                labId: this.agentConfig.labId.value || 'production'
            },
            methodsHits: {}
        };
        if (footprintsPacket && footprintsPacket.apps && footprintsPacket.apps[0] && footprintsPacket.apps[0].files) {
            footprintsPacket.apps[0].files.forEach(function (file) {
                if (!file.methods)
                    return;
                file.methods.forEach(function (method) {
                    var totalHits = 0;
                    if (!method.hits)
                        return;
                    method.hits.forEach(function (testIdxAndHits) {
                        totalHits += testIdxAndHits[1];
                    });
                    productionDataPacket.methodsHits[method.uniqueId] = totalHits;
                });
            });
        }
        this.collectionStartDate = now;
        return productionDataPacket;
    };
    ProductionFootprintsHandler.prototype.convertAndSubmitToServer = function (footprintsPacket) {
        var _this = this;
        var productionDataPacket = this.convertFootprintsToProductionData(footprintsPacket);
        return new Promise(function (resolve, reject) {
            var url = sl_routes_1.SLRoutes.productionV1(_this.agentConfig.buildSessionId.value);
            _this.httpClient.post(productionDataPacket, url, function (err) {
                err ? reject(err) : resolve();
            });
        });
    };
    /*
        In production listener we are in anonymous mode, and all hits will refer to single anonymous test.
        So we can there will be single array in "hits" array.
        In this inner array firs element will be always '0'(the index of test in array which contains only one - the anonymous),
        and the second element is the hits number.
     */
    ProductionFootprintsHandler.prototype.addHitsFromFootprints = function (files) {
        var _this = this;
        files.forEach(function (file) {
            file.methods.forEach(function (method) {
                _this.methodIdToHits[method.uniqueId] = method.hits[0][1];
            });
        });
    };
    ProductionFootprintsHandler.prototype.tryParseFileContent = function (fileContent) {
        try {
            var hitsData = JSON.parse(fileContent).methodsHits;
            this.logger.debug("Previous hit data parsed successfully, '%s' items loaded", Object.keys(hitsData).length);
            return hitsData;
        }
        catch (err) {
            this.logger.error("Error while parsing hits file content. ", err);
            return null;
        }
    };
    ProductionFootprintsHandler.prototype.validateConfig = function (config) {
        if (!config) {
            throw new Error("cfg cannot be null or undefined");
        }
        if (!config.labId.hasValue) {
            throw new Error("Configuration must contains labId");
        }
        if (!config.buildSessionId.hasValue) {
            throw new Error("Configuration must contains buildSessionId");
        }
    };
    ProductionFootprintsHandler.prototype.addHitsFromFile = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            fs.readFile(_this.filename, function (err, data) {
                if (err && err.code != FILE_NOT_FOUND_CODE) {
                    _this.logger.error("Error while trying to read previous hits data. ", err);
                }
                if (data != null) {
                    var hits = _this.tryParseFileContent(data.toString());
                    if (hits != null) {
                        _this.updateHits(hits);
                    }
                    else {
                        _this.logger.error("Could not load previous hits from file");
                    }
                }
                resolve();
            });
        });
    };
    ProductionFootprintsHandler.prototype.writeDataToFile = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var data = JSON.stringify(_this.toJSonObject());
            fs.writeFile(_this.filename, data, function (err) {
                if (err) {
                    _this.logger.error("Error while trying to write methods hits into file. ", err);
                    reject(err);
                }
                resolve();
            });
        });
    };
    ProductionFootprintsHandler.prototype.createFilePath = function (config) {
        var filename = this.combineArgsWithDash(config.buildSessionId.value, config.labId.value, process.pid) + ".json";
        var fileStorage = sl_env_vars_1.SlEnvVars.getFileStorage();
        if (fileStorage) {
            return path.join(fileStorage, filename);
        }
        return filename;
    };
    ProductionFootprintsHandler.prototype.combineArgsWithDash = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return args.join("-");
    };
    ProductionFootprintsHandler.prototype.updateHits = function (methodsHitFromFile) {
        var _this = this;
        Object.keys(methodsHitFromFile).forEach(function (methodId) {
            if (_this.methodIdToHits[methodId]) {
                _this.methodIdToHits[methodId] += parseInt(methodsHitFromFile[methodId]);
            }
            else {
                _this.methodIdToHits[methodId] = parseInt(methodsHitFromFile[methodId]);
            }
        });
    };
    ProductionFootprintsHandler.prototype.toJSonObject = function () {
        return {
            meta: this.metaData.toJsonObject(),
            methodsHits: this.methodIdToHits
        };
    };
    return ProductionFootprintsHandler;
}());
exports.ProductionFootprintsHandler = ProductionFootprintsHandler;
var MetaData = /** @class */ (function () {
    function MetaData(buildSessionId, labId) {
        this.buildSessionId = buildSessionId;
        this.labId = labId;
        this.createdAt = new Date().toLocaleString();
        this.pid = process.pid;
    }
    MetaData.prototype.toJsonObject = function () {
        var _this = this;
        this.lastModifiedAt = new Date().toLocaleString();
        var json = {};
        Object.keys(this).forEach(function (key) {
            json[key] = _this[key];
        });
        return json;
    };
    return MetaData;
}());
//# sourceMappingURL=production-footprints-handler.js.map