"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var constants_1 = require("../constants/constants");
var validation_utils_1 = require("../utils/validation-utils");
var SLRoutes = /** @class */ (function () {
    function SLRoutes() {
    }
    SLRoutes.agentsV1 = function () {
        return SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V1) + SLRoutes.toUri(SLRoutes.AGENTS);
    };
    SLRoutes.agentsV2 = function () {
        return SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V2) + SLRoutes.toUri(SLRoutes.AGENTS);
    };
    SLRoutes.agentsV3 = function () {
        return SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V3) + SLRoutes.toUri(SLRoutes.AGENTS);
    };
    SLRoutes.agentsV5 = function () {
        return SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V5) + SLRoutes.toUri(SLRoutes.AGENTS);
    };
    SLRoutes.testExecution = function () {
        return SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V3) + SLRoutes.toUri(SLRoutes.TEST_EXECUTION);
    };
    SLRoutes.endExecution = function (customerId, appName, buildName, branchName, environment) {
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(appName, "appName");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(customerId, "customerId");
        var result = SLRoutes.testExecution();
        var query = {
            customerId: customerId,
            appName: appName,
            buildName: buildName,
            branchName: branchName,
            environment: environment
        };
        result += SLRoutes.buildQueryParams(query);
        return result;
    };
    SLRoutes.externalData = function () {
        return SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V3) + SLRoutes.toUri(SLRoutes.EXTERNAL_DATA);
    };
    SLRoutes.externalReport = function () {
        return SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V1) + SLRoutes.toUri(SLRoutes.EXTERNAL_REPORT);
    };
    SLRoutes.configV2 = function (component, customerId, appName, branchName, testStage, version) {
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(component, "component");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(customerId, "customerId");
        branchName = branchName || "null";
        testStage = testStage || "null";
        appName = appName || "null";
        var prefix = SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V2) + SLRoutes.CONFIG;
        var pathParams = [customerId, appName, branchName, testStage, component, version];
        pathParams = pathParams.map(encodeURIComponent);
        pathParams.unshift(prefix);
        var url = pathParams.join(SLRoutes.SLASH);
        return url;
    };
    SLRoutes.buildSessionV2 = function (buildSessionId) {
        var result = SLRoutes.agentsV2() + SLRoutes.toUri(SLRoutes.BUILD_SESSION_ID) + SLRoutes.toUri(buildSessionId);
        return result;
    };
    SLRoutes.logSubmissionV2 = function () {
        var result = SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V2) + SLRoutes.LOG_SUBMISSION;
        return result;
    };
    SLRoutes.buildMappingV3 = function () {
        var result = SLRoutes.agentsV3() + SLRoutes.toUri(SLRoutes.BUILD_MAPPING);
        return result;
    };
    SLRoutes.footprintsV5 = function () {
        var result = SLRoutes.agentsV5() + SLRoutes.toUri(SLRoutes.FOOTPRINTS);
        return result;
    };
    SLRoutes.eventsV2 = function () {
        return SLRoutes.agentsV2() + SLRoutes.toUri(SLRoutes.EVENTS);
    };
    SLRoutes.productionV1 = function (buildSessionId) {
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(buildSessionId, "buildSessionId");
        var result = SLRoutes.SLASH + SLRoutes.toUri(SLRoutes.V1) + SLRoutes.toUri(SLRoutes.AGENTS) + SLRoutes.toUri(SLRoutes.PRODUCTION) + SLRoutes.toUri(SLRoutes.BSID) + SLRoutes.toUri(buildSessionId);
        return result;
    };
    SLRoutes.recommendedAgentV2 = function (component, customerId, appName, branchName, testStage) {
        if (!component) {
            throw new Error("'component' " + constants_1.Constants.Messages.CANNOT_BE_NULL_OR_UNDEFINED + ".");
        }
        var result = SLRoutes.agentsV2() + SLRoutes.toUri(component) + SLRoutes.toUri(SLRoutes.RECOMMENDED_VERSION);
        var query = {
            customerId: customerId,
            appName: appName,
            branch: branchName,
            envName: testStage
        };
        result += SLRoutes.buildQueryParams(query);
        return result;
    };
    SLRoutes.blobs = function (buildSessionId, blobId) {
        return SLRoutes.agentsV1() + SLRoutes.toUri(SLRoutes.BLOBS) + SLRoutes.toUri(buildSessionId) + SLRoutes.toUri(blobId);
    };
    SLRoutes.toUri = function (uri) {
        if (uri == null || uri.length == null || uri.length === 0) {
            return "";
        }
        return encodeURIComponent(uri) + SLRoutes.SLASH;
    };
    SLRoutes.buildQueryParams = function (paramsMap) {
        if (!paramsMap) {
            throw new Error("'paramsMap' cannot be null or undefined.");
        }
        var queryString = '';
        for (var key in paramsMap) {
            var value = paramsMap[key];
            queryString += SLRoutes.addQueryStringValue(key, value);
        }
        queryString = "?" + queryString;
        queryString = queryString.substring(0, queryString.length - 1); //Remove the last &.
        return queryString;
    };
    SLRoutes.addQueryStringValue = function (key, value) {
        if (!key && !value)
            return '';
        if (!value) {
            value = "";
        }
        var paramString = '';
        paramString += encodeURIComponent(key);
        paramString += "=";
        paramString += encodeURIComponent(value);
        paramString += "&";
        return paramString;
    };
    SLRoutes.SLASH = "/";
    SLRoutes.V1 = "v1";
    SLRoutes.V2 = "v2";
    SLRoutes.V3 = "v3";
    SLRoutes.V5 = "v5";
    SLRoutes.AGENTS = "agents";
    SLRoutes.EVENTS = "events";
    SLRoutes.PRODUCTION = "productiondata";
    SLRoutes.BSID = "bsid";
    SLRoutes.BUILD_SESSION_ID = "buildsession";
    SLRoutes.BUILD_MAPPING = "buildmapping";
    SLRoutes.RECOMMENDED_VERSION = "recommended";
    SLRoutes.CONFIG = "config";
    SLRoutes.LOG_SUBMISSION = "logsubmission";
    SLRoutes.FOOTPRINTS = "footprints";
    SLRoutes.TEST_EXECUTION = "testExecution";
    SLRoutes.EXTERNAL_DATA = "externaldata";
    SLRoutes.EXTERNAL_REPORT = "externalreport";
    SLRoutes.BLOBS = "blobs";
    return SLRoutes;
}());
exports.SLRoutes = SLRoutes;
//# sourceMappingURL=sl-routes.js.map