"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var validation_utils_1 = require("./utils/validation-utils");
var files_utils_1 = require("./utils/files-utils");
var ShortNameToFileMapper = /** @class */ (function () {
    function ShortNameToFileMapper(logger) {
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(logger, "logger");
        this.shortNameToFile = {};
        this.fileAlreadyAddedMap = {};
        this.isDuplicateResolves = false;
        this.logger = logger;
    }
    ShortNameToFileMapper.prototype.addFile = function (file) {
        file = files_utils_1.FilesUtils.adjustPathSlashes(file);
        if (this.fileAlreadyAddedMap[file]) {
            return;
        }
        var base = path.basename(file);
        this.addShortNameToFile(base, file);
        this.fileAlreadyAddedMap[file] = true;
    };
    ShortNameToFileMapper.prototype.resolveShortNameForFile = function (file) {
        file = files_utils_1.FilesUtils.adjustPathSlashes(file);
        if (!this.isDuplicateResolves) {
            this.findShortPathForDuplicates();
            this.isDuplicateResolves = true;
        }
        var pathParts = file.split("/");
        var counter = pathParts.length - 1;
        var shortestPath = null;
        while (counter >= 0 && shortestPath == null) {
            var currentShort = pathParts.slice(counter).join("/");
            if (!this.shortNameToFile[currentShort]) {
                this.logger.warn("could not find short name for '" + file + "'");
                shortestPath = currentShort;
            }
            else if (Array.isArray(this.shortNameToFile[currentShort]) &&
                !(this.shortNameToFile[currentShort].length > 1)) {
                this.logger.debug("found '" + currentShort + "' as  short name for '" + file + "'");
                shortestPath = currentShort;
            }
            counter--;
        }
        if (!shortestPath) {
            this.logger.warn("could not find short name for '" + file + "'");
            return file;
        }
        return shortestPath;
    };
    ShortNameToFileMapper.prototype.findShortPathForDuplicates = function () {
        var shortNames = Object.keys(this.shortNameToFile);
        for (var _i = 0, shortNames_1 = shortNames; _i < shortNames_1.length; _i++) {
            var shortName = shortNames_1[_i];
            if (this.shortNameToFile[shortName].length > 1) {
                this.mapDuplicates(this.shortNameToFile[shortName]);
            }
        }
    };
    ShortNameToFileMapper.prototype.mapDuplicates = function (duplicates) {
        for (var _i = 0, duplicates_1 = duplicates; _i < duplicates_1.length; _i++) {
            var file = duplicates_1[_i];
            var parts = file.split("/");
            var counter = parts.length - 2;
            while (counter >= 0) {
                var shortName = parts.slice(counter).join("/");
                this.addShortNameToFile(shortName, file);
                counter--;
            }
        }
    };
    ShortNameToFileMapper.prototype.addShortNameToFile = function (shortName, file) {
        this.shortNameToFile[shortName] = this.shortNameToFile[shortName] || [];
        this.shortNameToFile[shortName].push(file);
    };
    return ShortNameToFileMapper;
}());
exports.ShortNameToFileMapper = ShortNameToFileMapper;
//# sourceMappingURL=short-name-to-file-mapper.js.map