"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var events = require("events");
var WatchdogOptions = /** @class */ (function () {
    function WatchdogOptions() {
    }
    return WatchdogOptions;
}());
exports.WatchdogOptions = WatchdogOptions;
/**
 * Wraps timers to fire an "alarm" alarm after a given interval. Supports
 *
 * @export
 * @class Watchdog
 * @extends {events.EventEmitter}
 */
var Watchdog = /** @class */ (function (_super) {
    __extends(Watchdog, _super);
    function Watchdog(options, timers) {
        var _this = _super.call(this) || this;
        _this.options = options;
        _this.timers = timers;
        _this.handle = null;
        _this.pendingAlarmDuringSuspended = false;
        _this.suspended = false;
        _this.stopped = true;
        if (!options) {
            throw new Error("options is required");
        }
        if (!timers) {
            throw new Error("timers is required");
        }
        return _this;
    }
    Watchdog.prototype.abort = function () {
        if (this.handle) {
            this.timers.clearTimeout(this.handle);
            this.handle = null;
            this.pendingAlarmDuringSuspended = false;
        }
    };
    /**
     * Restarts the watchdog
     *
     * @memberOf Watchdog
     */
    Watchdog.prototype.reset = function () {
        var _this = this;
        this.abort();
        if (!this.stopped) {
            this.handle = this.timers.setTimeout(function () { _this.fireAlarm(); }, this.options.interval);
            if (this.options.unref) {
                this.handle.unref(); // Don't hold the process alive if this timer is still pending
            }
        }
    };
    /**
     * Stops the watchdog
     *
     *
     * @memberOf Watchdog
     */
    Watchdog.prototype.stop = function () {
        this.stopped = true;
        this.abort();
    };
    /**
     * Starts the watchdog
     *
     * @memberOf Watchdog
     */
    Watchdog.prototype.start = function () {
        this.stopped = false;
        this.reset();
    };
    /**
     * Returns the current status of the watchdog
     * @returns
     *
     * @memberOf Watchdog
     */
    Watchdog.prototype.getStatus = function () {
        return {
            pendingAlarmDuringSuspended: this.pendingAlarmDuringSuspended,
            running: !this.stopped,
            suspended: this.suspended,
        };
    };
    /**
     * Suspends this watchdog, which prevents it from firing events.
     *
     * @memberOf Watchdog
     */
    Watchdog.prototype.suspend = function () {
        this.suspended = true;
    };
    /**
     * Resumes this watchdog from suspended mode. If an alarm was fired while suspended, it will be fired now.
     *
     * @memberOf Watchdog
     */
    Watchdog.prototype.resume = function () {
        this.suspended = false;
        if (this.pendingAlarmDuringSuspended) {
            this.pendingAlarmDuringSuspended = false;
            this.fireAlarm();
        }
    };
    Watchdog.prototype.fireAlarm = function () {
        this.handle = null;
        if (this.suspended) {
            this.pendingAlarmDuringSuspended = true; //raise this flag and quit
        }
        else {
            try {
                this.emit("alarm", this);
            }
            catch (err) {
                // TODO: Log?
            }
        }
        if (this.options.autoReset) {
            this.reset();
        }
    };
    Watchdog.prototype.setInterval = function (newInterval) {
        if (newInterval <= 0)
            throw new Error("Invalid value for interval: " + newInterval);
        this.options.interval = newInterval;
    };
    Watchdog.prototype.getInterval = function () {
        return this.options.interval;
    };
    return Watchdog;
}(events.EventEmitter));
exports.Watchdog = Watchdog;
//# sourceMappingURL=watchdog.js.map